<?php

/**
 * Book Block Template.
 *
 * @param   array $block The block settings and attributes.
 * @param   string $content The block inner HTML (empty).
 * @param   bool $is_preview True during AJAX preview.
 * @param   (int|string) $post_id The post ID this block is saved to.
 */

// Create id attribute allowing for custom "anchor" value.
$id = 'book-' . $block['id'];
if( !empty( $block['anchor'] ) ) {
    $id = $block['anchor'];
}

// Create class attribute allowing for custom "className" and "align" values.
$className = 'book';
if( !empty( $block['className'] ) ) {
    $className .= ' ' . $block['className'];
}
if( !empty( $block['align'] ) ) {
    $className .= ' align' . $block['align'];
}

// Load values and assign defaults.

$title = get_field ( 'title' ) ?: 'Book title...';
$author = get_field( 'author' ) ?: 'Author name...';
$link = get_field( 'link' ) ?: 'Link to book...';
$description = get_field( 'description' );
$cover = get_field( 'cover' );
$background_color = get_field( 'background_color' );

?>
<div id="<?php echo esc_attr( $id ); ?>" class="<?php echo esc_attr( $className ); ?>">
	<span class="book-image">
		<img src="<?php echo $cover['url']; ?>">
	</span>
	<span class="book-details">
		<p><a href="<?php echo $link; ?>"><?php echo $title; ?></a></p>
		<p><?php echo $author; ?></p>
		<p><?php echo $description; ?></p>
	</span>
</div>
<style type="text/css">
	#<?php echo $id; ?> {
		background-color: <?php echo $background_color; ?>;
	}
</style>